@@ -27,6 +27,8 @@ sys.path.append(os.path.dirname(__file__))
 from PyQt4 import QtGui, QtCore, uic
 from PyQt4.QtCore import Qt
 
+import numpy as np
+
 import matplotlib as mpl
 if mpl.backends.backend is None: 
     mpl.use('Qt4Agg')
@@ -82,7 +84,9 @@ class Controls():
         self.ui.timelineSlider.connect(self.ui.timelineSlider,
                                          QtCore.SIGNAL("valueChanged(int)"),
                                          self.on_timeline_value_changed)
-        
+        self.ui.animationTime.connect(self.ui.animationTime,
+                                      QtCore.SIGNAL('returnPressed()'),
+                                      self.on_animation_time_return_pressed)
         self.ui.actionLoad.connect(self.ui.actionLoad, 
                                    QtCore.SIGNAL("triggered()"),
                                    self.load_hdf)
@@ -124,7 +128,7 @@ class Controls():
             msg = "Loaded db: %s" % self.path_to_hdf
             self.ui.statusbar.showMessage(msg, 3500)
             # Enablig the Animation button
-            self.ui.animation_btn.setEnabled(True)
+            self.animation()
             # Disabling all the rest
             self.ui.init_btn.setEnabled(False)
             self.ui.run_btn.setEnabled(False)
@@ -151,6 +155,8 @@ class Controls():
         else:
             #Raise the visio window
             self.visio.container.show()
+        # Enabling the animation
+        self.animation()
         
     
     def init(self):
@@ -183,8 +189,7 @@ class Controls():
                 h.fadvance()
                 
                 self.ui.time_label.setText("<b>" + str(h.t) + "</b>")
-            # Enabling the animation
-            self.animation()
+
                     
     def tstop_changed(self):
         
@@ -318,12 +323,29 @@ class Controls():
         self.ui.timelineSlider.setEnabled(True)
         self.ui.show()
     
-        
+    
+    
+    def on_animation_time_return_pressed(self):
+        "Getting the value from the text"
+        time = self.ui.animationTime.text()
+        try:
+            time = int (time)
+            time_list = self.manager.groups['t'].to_python()
+            time_list = np.around(time_list, 3)
+            time_list = time_list.tolist()
+            time_point_indx = time_list.index(time)
+            self.sync_visio_3d(time_point_indx)
+            self.ui.timelineSlider.setValue(time_point_indx)
+        except:
+            print "Value not present in the array."
+    
     def on_timeline_value_changed(self):
         """Draw the animation according to the value of the timeline"""
         
-        # cast to int from str
         time_point_indx = self.ui.timelineSlider.value()
+        self.sync_visio_3d(time_point_indx)    
+    
+    def sync_visio_3d(self, time_point_indx):
         
         var = self.ui.varToShow.text()
         var = str(var) # This will go with Py3
