@@ -134,7 +134,7 @@ class Visio(object):
         
         # ScalarBar and time_point
         self.colorbar = None
-        self.text = None
+        self.timelabel = None
     
 
     def picker_callback(self, picker):
@@ -296,6 +296,9 @@ class Visio(object):
     def draw_mayavi(self, x, y, z, d, edges):
         "Draw the surface the first time"
         
+        # rendering disabled
+        self.mayavi.visualization.scene.disable_render = True
+        
         points = mlab.pipeline.scalar_scatter(x, y, z, d/2.0)
         dataset = points.mlab_source.dataset
         dataset.point_data.get_array(0).name = 'diameter'
@@ -338,7 +341,7 @@ class Visio(object):
         self.dataset.point_data.update()
         src2 = mlab.pipeline.set_active_attribute(self.tube, 
                                                   point_scalars=scalar_name)
-        self.surf = mlab.pipeline.surface(src2, colormap='Blues')
+        self.surf = mlab.pipeline.surface(src2, colormap='blue-red')
         
     
     def show_variable_timecourse(self, var, time_point, 
@@ -346,6 +349,7 @@ class Visio(object):
         """Show an animation of all the section that have 
         the recorded variable among time"""
         
+        
         # Getting the new scalar
         new_scalar = self.get_var_data(var, time_point)
         
@@ -356,16 +360,24 @@ class Visio(object):
             print "Diameter length: %s New Scalar length: %s var: %s" %(len(d),
                                                                         len(new_scalar),
                                                                         var)
+        # ReEnable the rendering
+        self.mayavi.visualization.scene.disable_render = True
         
         self.redraw_color(new_scalar, var)
         
 
         if not self.colorbar:
             self.colorbar = mlab.colorbar(orientation='vertical')
-            self.text = mlab.text(0.05,0.05, str(time_point), width=0.05)
+            self.timelabel = mlab.text(0.05, 
+                                       0.05, 
+                                       str(time_point), 
+                                       width=0.05
+                                       )
         
         self.colorbar.data_range = [start_value, end_value]
-        self.text.text = str(self.manager.groups['t'][time_point])
+        self.timelabel.text = str(self.manager.groups['t'][time_point])
+        
+        self.mayavi.visualization.scene.disable_render = False
 
     
     def redraw_color(self, new_scalar, var):
